==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Lang/src/support/BreakpointConditionChecker.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_BREAKPOINT_CONDITION_CHECKER_H_
#define _U2_BREAKPOINT_CONDITION_CHECKER_H_

#include <QMutex>

#include <U2Lang/WorkflowContext.h>

#include "WorkflowBreakpointSharedInfo.h"

namespace U2 {

class AttributeScript;
class WorkflowScriptEngine;

class BreakpointConditionChecker {
    Q_DISABLE_COPY(BreakpointConditionChecker)
public:
    BreakpointConditionChecker(const QString &initConditionText,
                               Workflow::WorkflowContext *context = nullptr);
    ~BreakpointConditionChecker();

    void setContext(Workflow::WorkflowContext *context);
    bool evaluateCondition(const AttributeScript *conditionContext);

    void setConditionText(const QString &text);
    QString getConditionText() const;
    void setEnabled(bool enable);
    bool isEnabled() const;
    void setConditionParameter(BreakpointConditionParameter newParameter);
    BreakpointConditionParameter getConditionParameter() const;

private:
    QString conditionText;
    WorkflowScriptEngine *engine;
    bool enabled;
    BreakpointConditionParameter parameter;
    int lastConditionEvaluation;
    QMutex engineGuard;
};

}  // namespace U2

#endif  // _U2_BREAKPOINT_CONDITION_CHECKER_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/corelibs/U2Lang/src/support/BreakpointConditionChecker.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <QMutex>

#include <U2Lang/WorkflowContext.h>

#include "WorkflowBreakpointSharedInfo.h"

namespace U2 {

class AttributeScript;
class WorkflowScriptEngine;

class BreakpointConditionChecker {
    Q_DISABLE_COPY(BreakpointConditionChecker)
public:
    BreakpointConditionChecker(const QString& initConditionText,
                               Workflow::WorkflowContext* context = nullptr);
    ~BreakpointConditionChecker();

    void setContext(Workflow::WorkflowContext* context);
    bool evaluateCondition(const AttributeScript* conditionContext);

    void setConditionText(const QString& text);
    QString getConditionText() const;
    void setEnabled(bool enable);
    bool isEnabled() const;
    void setConditionParameter(BreakpointConditionParameter newParameter);
    BreakpointConditionParameter getConditionParameter() const;

private:
    QString conditionText;
    WorkflowScriptEngine* engine;
    bool enabled;
    BreakpointConditionParameter parameter;
    int lastConditionEvaluation;
    QMutex engineGuard;
};

}  // namespace U2
